#ifndef NT2_INCLUDE_FUNCTIONS_CENTER_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_CENTER_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/center.hpp>

#endif
